@@ -12,18 +12,15 @@
 #include <QHash>
 #include <QUrl>
 
-#include <kaccountsuiplugin.h>
+#include <KAccounts/KAccountsUiPlugin>
 
-namespace KDeclarative
-{
-class QmlObject;
-}
+class QQmlApplicationEngine;
 
-class OwnCloudWizard : public KAccountsUiPlugin
+class OwnCloudWizard : public KAccounts::KAccountsUiPlugin
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kde.kaccounts.UiPlugin")
-    Q_INTERFACES(KAccountsUiPlugin)
+    Q_INTERFACES(KAccounts::KAccountsUiPlugin)
 
 public:
     explicit OwnCloudWizard(QObject *parent = nullptr);
@@ -37,7 +34,7 @@ public:
 
 private:
     QHash<QString, int> m_services;
-    KDeclarative::QmlObject *m_object;
+    QQmlApplicationEngine *m_engine;
     KPluginMetaData m_data;
 };
 
